/**
 *+------------------------------------------------------------------------+
 *| Licensed Materials - Property of IBM                                   |
 *| (C) Copyright IBM Corp. 2012.  All Rights Reserved.              |
 *|                                                                        |
 *| US Government Users Restricted Rights - Use, duplication or disclosure |
 *| restricted by GSA ADP Schedule Contract with IBM Corp.                 |
 *+------------------------------------------------------------------------+
 */
command {
   
   name "run"
   description "Execute a scripted response file."
	 contexts "console", "commandLine"
	 
	 instance {	    
	    invoke {
	       
	         def filename = arguments["filename"]	       
		     		     
		     def file = new java.io.File(filename)		     
		     if( file.exists() ) {
		     		def script = com.ibm.edp.rfe.model.ModelUtil.loadScript(file)
		     		if (!script.hasScriptVersion()) {
	       				println('WARNING: the property \'rfe_script_version\' is not defined.  Validate the script to prevent potential errors at runtime.') 
	       			}
		     		sprintln "Running $file"
		     		def opts = [:]
		     		def options = switches["-opt"]?switches["-opt"]["-opt"]:null
		     		if(options) {
		     		   options.split(",").each{
		     		      opts.put(it, true)
		     		   }
		     		}
		     		def result = com.ibm.edp.rfe.response.dsl.rt.GroovyResponse.runResponseFile( file, opts )
					
					session.setReturnCode( result.exitValue() )
					 
		     		if(result.exitValue()) {
		     		   sprintln "Script execution returned non-zero result"
		     		} else {
		     		   sprintln "Script execution finished successfully"
		     		}  
		     } else {
		        sprintln "$filename does not exist"
		     }
		     
		     if ( session.getContexts().find{ it == "commandLine" } != null ) {
     			session.setSystemQuit()
		     }
	    }
	 }
	 
	 arguments {	     
	     filename {
	        datatype "filename"
	        description "Scripted response file to execute."	        	        
	     }	
         "-opt" {
	        datatype "switch"
	        optional true
	        description "Options to use when executing the scripted response file."                
			   "-opt" {
			      description "Provide comma-separated list of options."  
			   }	 	       	
	     }	 		          	     
	 }
}