/*
*+------------------------------------------------------------------------+
*| Licensed Materials - Property of IBM                                   |
*| (C) Copyright IBM Corp. 2012.  All Rights Reserved.              |
*|                                                                        |
*| US Government Users Restricted Rights - Use, duplication or disclosure |
*| restricted by GSA ADP Schedule Contract with IBM Corp.                 |
*+------------------------------------------------------------------------+
*/

command {
	name "update"
	description "Add update operation for a named product"
	contexts "create", "edit"
	instance {
		invoke {
			def pid = arguments["id"]
			def version = switches["-version"]?switches["-version"]["-version"]:null			
			def platform = switches["-platform"]?switches["-platform"]["-platform"]:null
			
			def pkgs = com.ibm.edp.rfe.model.ModelUtil.findPackages(pid,version)
			if(pkgs.size() > 0){
				def pkg = pkgs[pkgs.size()-1]
				
				def list = com.ibm.edp.rfe.model.ScriptList.getInstance()
				def script = list.getCurrentScript()

				def pg = new com.ibm.edp.rfe.model.PackageGroup(name: "env")
				script.addGroup( pg )
				
				def pkgname = com.ibm.edp.rfe.model.ScriptNaming.getPackageName( pkg.getName() )
				def p = new com.ibm.edp.rfe.model.Package(name: pkgname, identity: new com.ibm.edp.rfe.model.PackageIdentity() )
				script.addPackage(p)
	
				def cmd = new com.ibm.edp.rfe.model.Command(name: "update", packages: [p], group: pg)
				script.addCommand( cmd )
				def queryRuntime = com.ibm.edp.rfe.console.query.QueryRuntime.getInstance()
				def inputValues = [packageId:pid, version: version, platform: platform, pkg: p, env: pg, cmd: cmd]
				queryRuntime.run(session, "update", inputValues)

				sprintln "Update command has been added successfully"
									   
			} else {
			   sprintln "Package identified by $pid can not be found"
			}

		}
	}
	arguments {
		"id" {
		   datatype "list"
		   values {
			  com.ibm.edp.rfe.model.ModelUtil.getPackageNames().collect{ it.key }
		   }
		   description "Enter package identifier."
		}
		
		"-version" {
		   datatype "switch"
		   optional true
		   description "Specifies package version to update to."
		 
				 "-version" {
					 description "Enter package version."
				   datatype "list"
				   values {
					   com.ibm.edp.rfe.model.ModelUtil.getAllVersions( null )
				   }
				 }
		}
	  
		"-platform" {
		   datatype "switch"
		   optional true
		   description "Specifies package platform."
		 
				 "-platform" {
					 description "Enter package platform."
				   datatype "list"
				   values {
							com.ibm.edp.rfe.model.ModelUtil.getPlatforms( null, null ).collect{ it.key }
				   }
				 }
		}
	}
}
