/*
 *+------------------------------------------------------------------------+
 *| Licensed Materials - Property of IBM                                   |
 *| (C) Copyright IBM Corp. 2012.  All Rights Reserved.              |
 *|                                                                        |
 *| US Government Users Restricted Rights - Use, duplication or disclosure |
 *| restricted by GSA ADP Schedule Contract with IBM Corp.                 |
 *+------------------------------------------------------------------------+
 */
query_script_version '1.0.0'

packageid 'com.ibm.rational.clearcase.nt_i386'
packageversion '[8.0.0,8.1.0)'

query_order {	
	custom {
		install {
			commonlicensing
			processstopping
			bypassalbdcheck
			serviceaccountdomain
			serviceaccountuser
			serviceaccountpassword
			serviceaccountgroup
			registryserver
			windowsregion
			unixregion
			mailserver
			remoteadmin
			mvfscasesensitive
			mvfscasepreserving
			mvfsdriveletter
			mvfsscalingfactor
			mvfsvobmnodes
			mvfscleartextmnodes
			ccfs
			customizeccexplorerpopupmenu
			ccexplorerpopupmenufile
			customizeccexplorertoolshortcuts
			ccexplorertoolshortcutsfile
			desktopshortcut
			useatrialicensing
			atrialicensingtype
			atrialicensinghost
			atrialicensingkey
			teamconvdir
		}
		uninstall {
			serviceaccountuser
			serviceaccountpassword
			teamconvdir
		}
		update{
			commonlicensing
			processstopping
			bypassalbdcheck
			serviceaccountdomain
			serviceaccountuser
			serviceaccountpassword
			serviceaccountgroup
			useatrialicensing
			atrialicensingtype
			atrialicensinghost
			atrialicensingkey
			teamconvdir
		}
	}
}

//def S_IPv4_REGEX = "^(\\d{1,2}|1\\d\\d|2[0-4]\\d|25[0-5])\\.(\\d{1,2}|1\\d\\d|2[0-4]\\d|25[0-5])\\." + "(\\d{1,2}|1\\d\\d|2[0-4]\\d|25[0-5])\\.(\\d{1,2}|1\\d\\d|2[0-4]\\d|25[0-5])$"
//def S_IPv6_REGEX = "(^(:{2}((([0-9A-Fa-f]{1,4})?)|(([0-9A-Fa-f]{1,4}:){1,5}[0-9A-Fa-f]{1,4})))$)|" + "(^(([0-9A-Fa-f]{1,4}:){7}[0-9A-Fa-f]{1,4})$|^(([0-9A-Fa-f]{1,4}:){5}:((([0-9A-Fa-f]{1,4}:)[0-9A-Fa-f]{1,4})|" + "(([0-9A-Fa-f]{1,4})?)))$|^(([0-9A-Fa-f]{1,4}:){4}:((([0-9A-Fa-f]{1,4}:){1,2}[0-9A-Fa-f]{1,4})|" + "(([0-9A-Fa-f]{1,4})?)))$|^(([0-9A-Fa-f]{1,4}:){3}:((([0-9A-Fa-f]{1,4}:){1,3}[0-9A-Fa-f]{1,4})|" + "(([0-9A-Fa-f]{1,4})?)))$|^(([0-9A-Fa-f]{1,4}:){2}:((([0-9A-Fa-f]{1,4}:){1,4}[0-9A-Fa-f]{1,4})|" + "(([0-9A-Fa-f]{1,4})?)))$|^(([0-9A-Fa-f]{1,4}:):((([0-9A-Fa-f]{1,4}:){1,5}[0-9A-Fa-f]{1,4})|(([0-9A-Fa-f]{1,4})?)))$)"
//def S_HOST_NAME_REGEX = "^([a-zA-Z0-9]([a-zA-Z0-9\\-]*))$"
//def S_DNS_HOST_NAME_REGEX = "^([a-zA-Z0-9]([a-zA-Z0-9\\-]{0,61}[a-zA-Z0-9])?\\.)+[a-zA-Z0-9]{2,61}$"
//def S_LOCAL_DOMAIN_REGEX = "^([a-zA-Z0-9]([a-zA-Z0-9\\-]{0,61}[a-zA-Z0-9])?\\.)+localdomain"


query {
	id "commonlicensing"
	required false
	dependencies advancedType
	label "Enter the TCP/IP port and host name of one or more license servers"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
    	com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.RCL_PortAtHost", commonlicensing)
	}
}

query {
	id "processstopping"
	required true
	dependencies advancedType
	label "Stop running processes associated with the product"
	labelType "text"
	inputType "list"
	inputDefault "Yes"
    inputOptions "Yes,No"
    inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (processstopping.equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.StopRunningProcesses", "true")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.StopRunningProcesses", "false")
		}
	}
}

query {
	id "bypassalbdcheck"
	required false
	dependencies features
	label "Bypass ALBD account check"
	labelType "text"
	inputType "list"
	inputDefault "No"
	inputOptions "Yes,No"
    inputIgnoreCase true
	condition {
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (bypassalbdcheck.equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_DisableAccountConfiguration", "true")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_DisableAccountConfiguration", "false")
		}
	}
}

query {
	id "serviceaccountdomain"
	required true
	dependencies features
	label "Service Account domain"
	labelType "text"
	inputType "text"
	condition {
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_AccountDomain", serviceaccountdomain)
	}
}

query {
	id "serviceaccountuser"
	required true
	dependencies features
	label "Service Account user name"
	labelType "text"
	inputType "text"
	condition {
	}
	validation {
		if (serviceaccountuser.size() > 20) {
			println "The service account user name must be less than 20 characters long."
			return false
		}
		if ((serviceaccountuser.lastIndexOf('.') > (serviceaccountuser.size() - 1)) && (serviceaccountuser.indexOf(',') != -1 && serviceaccountuser.indexOf('"') != -1 && serviceaccountuser.indexOf('/') != -1 && serviceaccountuser.indexOf('\\') != -1 && serviceaccountuser.indexOf('[') != -1 && serviceaccountuser.indexOf(']') != -1 && serviceaccountuser.indexOf(':') != -1 && serviceaccountuser.indexOf('|') != -1 && serviceaccountuser.indexOf('<') != -1 && serviceaccountuser.indexOf('>') != -1 && serviceaccountuser.indexOf('+') != -1 && serviceaccountuser.indexOf('=') != -1 && serviceaccountuser.indexOf(';') != -1 && serviceaccountuser.indexOf('?') != -1 && serviceaccountuser.indexOf('*') != -1)) {
			println "Invalid character in the user name. Please make sure that none of the following characters are present in the user name provided: , \" / \\ [ ] : | < > + = ; ? *"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_ServerProcessUserID", serviceaccountuser)
	}
}

query {
	id "serviceaccountpassword"
	required true
	dependencies features
	label "Service Account password"
	labelType "text"
	inputType "password"
	condition {
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		serviceaccountpassword = com.ibm.edp.rfe.model.ModelUtil.encryptValue( serviceaccountpassword )
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_ServerProcessPassword", serviceaccountpassword)
	}
}

query {
	id "serviceaccountgroup"
	required true
	dependencies features
	label "ClearCase Administrator group"
	labelType "text"
	inputType "text"
	condition {
	}
	validation {
		if (serviceaccountgroup.size() > 256) {
			println "The service account group name must be less than 256 characters."
			return false	
		}
		if (serviceaccountgroup.equalsIgnoreCase(serviceaccountuser)) {
			println "The service account group name must be different than the service account user name."
			return false
		} 
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_AdminGroup", serviceaccountgroup)
	}
}

query {
	id "registryserver"
	required true
	dependencies features
	label "Registry server host name"
	labelType "text"
	inputType "text"
	condition {
	}
	validation {
		if (registryserver.size() > 256) {
			println "The registry server host name must be less than 256 characters."
			return false
		}
		if (registryserver.count("/") > 0 && registryserver.count("\\") > 0 && registryserver.count("[") > 0 && registryserver.count("]") > 0 && registryserver.count("\"") > 0 
			&& registryserver.count(":") > 0 && registryserver.count(";") > 0 && registryserver.count("|") > 0 && registryserver.count("<") > 0 && registryserver.count(">") > 0 
			&& registryserver.count("+") > 0 && registryserver.count("=") > 0 && registryserver.count(",") > 0 && registryserver.count("?") > 0 && registryserver.count("*") > 0 
			&& registryserver.count("_") > 0) {
			println "Invalid character in the registry server name"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_RegSvrHostName", registryserver)
	}
}

query {
	id "windowsregion"
	required true
	dependencies features
	label "Windows registry region"
	labelType "text"
	inputType "text"
	condition {
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_RegWinRegionName", windowsregion)
	}
}

query {
	id "unixregion"
	required false
	dependencies features
	label "UNIX registry region"
	labelType "text"
	inputType "text"
	condition {
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_RegUNIXRegionName", unixregion)
	}
}

query {
	id "mailserver"
	required false
	dependencies features
	label "SMTP mail server host name"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		if (mailserver.count("/") > 0 && mailserver.count("\\") > 0 && mailserver.count("[") > 0 && mailserver.count("]") > 0 && mailserver.count("\"") > 0 
			&& mailserver.count(":") > 0 && mailserver.count(";") > 0 && mailserver.count("|") > 0 && mailserver.count("<") > 0 && mailserver.count(">") > 0 
			&& mailserver.count("+") > 0 && mailserver.count("=") > 0 && mailserver.count(",") > 0 && mailserver.count("?") > 0 && mailserver.count("*") > 0 
			&& mailserver.count("_") > 0) {
			println "Invalid character in the mail server name"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_RegSMTPHostName", mailserver)
	}
}

query {
	id "remoteadmin"
	required false
	dependencies features
	label "Do you want to disable remote administration for ClearCase"
	labelType "text"
	inputType "list"
	inputDefault "Yes"
	inputOptions "Yes,No"
    inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (remoteadmin.equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_RemoteAdministrationAccess", "1")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_RemoteAdministrationAccess", "0")
		}
	}
}

query {
	id "mvfscasesensitive"
	required false
	dependencies features
	label "Do you want to use Windows-style file lookup that is not case-sensitive"
	labelType "text"
	inputType "list"
	inputDefault "Yes"
	inputOptions "Yes,No"
    inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes") && com.ibm.edp.rfe.model.ModelUtil.getFeatures(pkg).containsValue("com.ibm.rational.clearcase.mvfs")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (mvfscasesensitive.equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_MVFSCaseInsensitivity", "1")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_MVFSCaseInsensitivity", "0")
		}
	}
}

query {
	id "mvfscasepreserving"
	required false
	dependencies features
	label "Do you want to use preserve the case of view-private filenames"
	labelType "text"
	inputType "list"
	inputDefault "No"
	inputOptions "Yes,No"
    inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes") && mvfscasesensitive.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (mvfscasepreserving .equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_MVFSCasePreserved", "1")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_MVFSCasePreserved", "0")
		}
		if (mvfscasesensitive.equalsIgnoreCase("Yes") && mvfscasepreserving.equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.MVFSCIFlag", "3")
		}
		else if (mvfscasesensitive.equalsIgnoreCase("No") && mvfscasepreserving.equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.MVFSCIFlag", "2")
		}
		else if (mvfscasesensitive.equalsIgnoreCase("Yes") && mvfscasepreserving.equalsIgnoreCase("No")) {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.MVFSCIFlag", "1")
		}
		else if (mvfscasesensitive.equalsIgnoreCase("No") && mvfscasepreserving.equalsIgnoreCase("No")) {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.MVFSCIFlag", "0")
		}
	}
}

query {
	id "mvfsdriveletter"
	required false
	dependencies features
	label "Drive letter used to mount dynamic views"
	labelType "text"
	inputType "list"
	inputDefault "M:"
	inputOptions "M:,N:,O:,P:,Q:,R:,S:,T:,U:,V:,W:,X:,Y:,Z:"
	condition {
		advancedType.equalsIgnoreCase("Yes") && com.ibm.edp.rfe.model.ModelUtil.getFeatures(pkg).containsValue("com.ibm.rational.clearcase.mvfs")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_DynamicViewsDriveLetter", mvfsdriveletter)
	}
}

query {
	id "mvfsscalingfactor"
	required true
	dependencies features
	label "Scaling factor for initializing MVFS cache size"
	labelType "text"
	inputType "list"
	inputDefault "1"
	inputOptions "0,1,2,3,4,5"
	condition {
		advancedType.equalsIgnoreCase("Yes") && com.ibm.edp.rfe.model.ModelUtil.getFeatures(pkg).containsValue("com.ibm.rational.clearcase.mvfs")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_ScalingFactor", mvfsscalingfactor)
	}
}

query {
	id "mvfsvobmnodes"
	required true
	dependencies features
	label "Maximum number of mnodes to keep on the VOB free list"
	labelType "text"
	inputType "text"
	inputDefault {
		if (mvfsscalingfactor == "0") {
			"0"
		}
		else {
			def scalingfactor = Integer.parseInt(mvfsscalingfactor, 10)
			def vobmnodes = (scalingfactor + 1) * 900
			Integer.toString( vobmnodes, 10)
		}
	}
	condition {
		advancedType.equalsIgnoreCase("Yes") && com.ibm.edp.rfe.model.ModelUtil.getFeatures(pkg).containsValue("com.ibm.rational.clearcase.mvfs")
	}
	validation {
		if (!mvfsvobmnodes.isInteger()) {
			println "The value must be an integer"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_MaxNumMnodesKeepOnVOBFreeList", mvfsvobmnodes)
	}
}

query {
	id "mvfscleartextmnodes"
	required true
	dependencies features
	label "Maximum number of mnodes to keep on the cleartext free list"
	labelType "text"
	inputType "text"
	inputDefault {
		if (mvfsscalingfactor == "0") {
			"0"
		}
		else {
			"1800"
		}
	}
	condition {
		advancedType.equalsIgnoreCase("Yes") && com.ibm.edp.rfe.model.ModelUtil.getFeatures(pkg).containsValue("com.ibm.rational.clearcase.mvfs")
	}
	validation {
		if (!mvfscleartextmnodes.isInteger()) {
			println "The value must be an integer"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_MaxNumMnodesKeepOnCleartextFreeList", mvfscleartextmnodes)
	}
}

query {
	id "ccfs"
	required false
	dependencies features
	label "Enable ClearCase File Server"
	labelType "text"
	inputType "list"
	inputDefault "Yes"
	inputOptions "Yes,No"
    inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (ccfs.equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_EnableCCFS", "1")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_EnableCCFS", "0")
		}
	}
}

query {
	id "customizeccexplorerpopupmenu"
	required false
	dependencies features
	label "Do you want to specify a pop-up menu customization file for ClearCase Explorer"
	labelType "text"
	inputType "list"
	inputDefault "No"
	inputOptions "Yes,No"
    inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (customizeccexplorerpopupmenu.equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_CCExplorerContextMenuCustomMenu", "true")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_CCExplorerContextMenuCustomMenu", "false")
		}
	}
}

query {
	id "ccexplorerpopupmenufile"
	required false
	dependencies features
	label "Pop-up menu customization file location for ClearCase Explorer"
	labelType "text"
	inputType "text"
	condition {
		customizeccexplorerpopupmenu.equalsIgnoreCase("Yes")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_CCExplorerContextMenuLocation", ccexplorerpopupmenufile)
	}
}

query {
	id "customizeccexplorertoolshortcuts"
	required false
	dependencies features
	label "Do you want to specify a tool shortcuts customization file for ClearCase Explorer"
	labelType "text"
	inputType "list"
	inputDefault "No"
	inputOptions "Yes,No"
    inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (customizeccexplorertoolshortcuts.equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_CCExplorerToolShortcutsUseShortcut", "true")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_CCExplorerToolShortcutsUseShortcut", "false")
		}
	}
}

query {
	id "ccexplorertoolshortcutsfile"
	required false
	dependencies features
	label "Tool shortcuts customization file location for ClearCase Explorer"
	labelType "text"
	inputType "text"
	condition {
		customizeccexplorertoolshortcuts.equalsIgnoreCase("Yes")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_CCExplorerToolShortcutsLocation", ccexplorertoolshortcutsfile)
	}
}

query {
	id "desktopshortcut"
	required false
	dependencies features
	label "Create a shortcut for ClearCase Explorer on the desktop"
	labelType "text"
	inputType "list"
	inputDefault "No"
	inputOptions "Yes,No"
    inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
	}
	action {
		if (desktopshortcut.equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_CCExplorerCreateShortcut", "true")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_CCExplorerCreateShortcut", "false")
		}
	}
}

query {
	id "useatrialicensing"
	required false
	dependencies features
	label "Use ClearCase Atria licensing"
	labelType "text"
	inputType "list"
	inputDefault "No"
	inputOptions "No,Yes"
    inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
	}
	action {
		if (useatrialicensing.equalsIgnoreCase("No")) {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_LICENSE_MANAGER", "IBMRCL")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CC_LICENSE_MANAGER", "ATRIA")
		}
	}
}

query {
	id "atrialicensingtype"
	required false
	dependencies features
	label "Where is your license server"
	labelType "text"
	inputType "list"
	inputDefault "Remote"
	inputOptions "Remote,Local"
    inputIgnoreCase true
	condition {
		useatrialicensing.equalsIgnoreCase("Yes")
	}
	validation {
	}
	action {
		if (atrialicensingtype.equalsIgnoreCase("Remote")) {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.ATRIA_HOST_IS_REMOTE", "true")
		} else {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.ATRIA_HOST_IS_REMOTE", "false")
		}
	}
}

query {
	id "atrialicensinghost"
	required false
	dependencies features
	label "Remote license server host name"
	labelType "text"
	inputType "text"
	condition {
		useatrialicensing.equalsIgnoreCase("Yes") && atrialicensingtype.equalsIgnoreCase("Remote")
	}
	validation {
		if (atrialicensinghost.count("/") > 0 && atrialicensinghost.count("\\") > 0 && atrialicensinghost.count("[") > 0 && atrialicensinghost.count("]") > 0 && atrialicensinghost.count("\"") > 0 
			&& atrialicensinghost.count(":") > 0 && atrialicensinghost.count(";") > 0 && atrialicensinghost.count("|") > 0 && atrialicensinghost.count("<") > 0 && atrialicensinghost.count(">") > 0 
			&& atrialicensinghost.count("+") > 0 && atrialicensinghost.count("=") > 0 && atrialicensinghost.count(",") > 0 && atrialicensinghost.count("?") > 0 && atrialicensinghost.count("*") > 0 
			&& atrialicensinghost.count("_") > 0) {
			println "Invalid character in the license server name"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.ATRIA_REMOTE_HOSTNAME", atrialicensinghost)
	}
}

query {
	id "atrialicensingkey"
	required false
	dependencies features
	label "Local license keys"
	labelType "text"
	inputType "text"
	condition {
		useatrialicensing.equalsIgnoreCase("Yes") && atrialicensingtype.equalsIgnoreCase("Local")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.ATRIA_LOCAL_KEY", atrialicensingkey)
	}
}

query {
	id "teamconvdir"
	required true
	dependencies features
	label "Enter the TCP/IP port and host name of one or more license servers"
	labelType "text"
	inputType "none"
	inputDefault {
		if (installLocation) {
			teamconvdir = installLocation.replaceAll("\\\\", "/")
		}
		else {
			teamconvdir = com.ibm.edp.rfe.model.ModelUtil.getDefaultInstallLocation( packageId, version, platform )
			teamconvdir = teamconvdir.replaceAll("\\\\", "/")
		}
		
	}
	condition {
		// This will never be shown
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (installLocation) {
			teamconvdir = installLocation.replaceAll("\\\\", "/")
		}
		else {
			teamconvdir = com.ibm.edp.rfe.model.ModelUtil.getDefaultInstallLocation( packageId, version, platform )
			teamconvdir = teamconvdir.replaceAll("\\\\", "/")
		}
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.Team_Conv_InstallDirectory", teamconvdir)
	}
}
