/*
 *+------------------------------------------------------------------------+
 *| Licensed Materials - Property of IBM                                   |
 *| (C) Copyright IBM Corp. 2012.  All Rights Reserved.              |
 *|                                                                        |
 *| US Government Users Restricted Rights - Use, duplication or disclosure |
 *| restricted by GSA ADP Schedule Contract with IBM Corp.                 |
 *+------------------------------------------------------------------------+
 */
query_script_version '1.0.0'

packageid 'com.ibm.rational.clearcase.sol_x86'
packageversion '[8.0.0,8.1.0)'

query_order {
	custom {
		install {
			commonlicensing
			tempdirectory
			registryserver
			unixregion
			mailserver
			mvfsrebuildmodule
			mvfskernelpath
			useatrialicensing
			atrialicensingtype
			atrialicensinghost
			atrialicensingkey
		}
		uninstall {
		}
	}
}

query {
	id "commonlicensing"
	required false
	dependencies features
	label "Enter the TCP/IP port and host name of one or more license servers"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.RCL_PortAtHost", commonlicensingserver)
	}
}

query {
	id "tempdirectory"
	required false
	dependencies features
	label "Enter a temporary directory used to cache files during installation. The files are removed after the installation finishes "
	labelType "text"
	inputType "text"
	inputDefault "/tmp"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.Common_TempDir", tempdirectory)
	}
}

query {
	id "registryserver"
	required true
	dependencies features
	label "Registry server host name"
	labelType "text"
	inputType "text"
	condition {
	}
	validation {
		registryserver.size() < 256
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_RegSvrHostName", registryserver)
	}
}

query {
	id "unixregion"
	required false
	dependencies features
	label "UNIX registry region"
	labelType "text"
	inputType "text"
	condition {
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_RegUNIXRegionName", unixregion)
	}
}

query {
	id "mailserver"
	required false
	dependencies features
	label "SMTP mail server host name"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_RegSMTPHostName", mailserver)
	}
}

query {
	id "mvfsrebuildmodule"
	required false
	dependencies features
	label "Do you want to rebuild the MVFS module during installation or use a prebuild module: "
	labelType "text"
	inputType "list"
	inputDefault "No install pre-built MVFS"
	inputOptions "Yes rebuild MVFS using current kernel,No install pre-built MVFS"
	condition {
		(advancedType.equalsIgnoreCase("Yes"))&& (com.ibm.edp.rfe.model.ModelUtil.getFeatures(pkg).containsValue("com.ibm.rational.clearcaseunix.CC_FULL") || com.ibm.edp.rfe.model.ModelUtil.getFeatures(pkg).containsValue("com.ibm.rational.clearcaseunix.CC_MIN_STD_X"))
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (mvfsrebuildmodule.equalsIgnoreCase("Yes rebuild MVFS using current kernel")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_MVFSModuleRebuild", "1")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_MVFSModuleRebuild", "0")
		}
	}
}

query {
	id "mvfskernelpath"
	required false
	dependencies features
	label "Enter the path to your top level kernel source directory: "
	labelType "text"
	inputType "text"
	condition {
		mvfsrebuildmodule.equalsIgnoreCase("Yes rebuild MVFS using current kernel")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_MVFSModuleKernelPath", mvfskernelpath)
	}
}

query {
	id "useatrialicensing"
	required false
	dependencies features
	label "Use ClearCase Atria licensing"
	labelType "text"
	inputType "list"
	inputDefault "No"
	inputOptions "Yes,No"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
	}
	action {
		if (useatrialicensing.equalsIgnoreCase("No")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_LICENSE_MANAGER", "IBMRCL")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.CC_LICENSE_MANAGER", "ATRIA")
		}
	}
}

query {
	id "atrialicensingtype"
	required false
	dependencies features
	label "Where is your license server"
	labelType "text"
	inputType "list"
	inputDefault "Remote"
	inputOptions "Remote,Local"
	condition {
		useatrialicensing.equalsIgnoreCase("Yes")
	}
	validation {
	}
	action {
		if (atrialicensingtype.equalsIgnoreCase("Remote")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.ATRIA_HOST_IS_REMOTE", "true")
		} else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.ATRIA_HOST_IS_REMOTE", "false")
		}
	}
}

query {
	id "atrialicensinghost"
	required false
	dependencies features
	label "Remote license server host name"
	labelType "text"
	inputType "text"
	condition {
		useatrialicensing.equalsIgnoreCase("Yes") && atrialicensingtype.equalsIgnoreCase("Remote")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.ATRIA_REMOTE_HOSTNAME", atrialicensinghost)
	}
}

query {
	id "atrialicensingkey"
	required false
	dependencies features
	label "Local license keys"
	labelType "text"
	inputType "text"
	condition {
		useatrialicensing.equalsIgnoreCase("Yes") && atrialicensingtype.equalsIgnoreCase("Local")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.ATRIA_LOCAL_KEY", atrialicensingkey)
	}
}