/*
 *+------------------------------------------------------------------------+
 *| Licensed Materials - Property of IBM                                   |
 *| (C) Copyright IBM Corp. 2012.  All Rights Reserved.              |
 *|                                                                        |
 *| US Government Users Restricted Rights - Use, duplication or disclosure |
 *| restricted by GSA ADP Schedule Contract with IBM Corp.                 |
 *+------------------------------------------------------------------------+
 */
query_script_version '1.0.0'

packageid 'com.ibm.rational.clearquest.linux_x86'
packageversion '[8.0.0,8.1.0)'

query_order {
	custom {
		install {
			commonlicensing
			tempdirectory
			remotehelptype
			customremotehelpurl
			enableemailnotification
			smtpserver
			emailfromfield
		}
		update{
			commonlicensing
		}
	}
}

query {
	id "remotehelptype"
	required true
	dependencies features
	label "Remote Help System"
	labelType "text"
	inputType "list"
	inputDefault "remote"
	inputOptions "remote,local,custom"
	inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.help.option", remotehelptype)
	}
}

query {
	id "customremotehelpurl"
	required true
	dependencies features
	label "Remote Help URL"
	labelType "text"
	inputType "text"
	condition {
	   remotehelptype.equalsIgnoreCase("custom")
	}
	validation {
    	if (!customremotehelpurl && customremotehelpurl.trim().length() <= 0) {
			println "The remote help URL is required. Please provide a value."
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.help.url", customremotehelpurl)
	}
}

query {
	id "commonlicensing"
	required false
	dependencies features
	label "Enter the TCP/IP port and host name of one or more license servers"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.RCL_PortAtHost", commonlicensing)
	}
}

query {
	id "tempdirectory"
	required false
	dependencies features
	label "Enter a temporary directory used to cache files during installation. The files are removed after the installation finishes "
	labelType "text"
	inputType "text"
	inputDefault "/tmp"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.Common_TempDir", tempdirectory)
	}
}

query {
	id "enableemailnotification"
	required true
	dependencies features
	label "Enable E-mail notification"
	inputType "list"
	inputDefault "No"
	inputOptions "Yes,No"
	inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (enableemailnotification.equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CQUseEmailNotification", "1")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CQUseEmailNotification", "0")
		}
	}
}

query {
	id "smtpserver"
	required true
	dependencies features
	label "Outgoing SMTP server"
	labelType "text"
	inputType "text"
	condition {
	   enableemailnotification.equalsIgnoreCase("Yes")
	}
	validation {
		if (smtpserver.count("/") > 0 && smtpserver.count("\\") > 0 && smtpserver.count("[") > 0 && smtpserver.count("]") > 0 && smtpserver.count("\"") > 0 
			&& smtpserver.count(":") > 0 && smtpserver.count(";") > 0 && smtpserver.count("|") > 0 && smtpserver.count("<") > 0 && smtpserver.count(">") > 0 
			&& smtpserver.count("+") > 0 && smtpserver.count("=") > 0 && smtpserver.count(",") > 0 && smtpserver.count("?") > 0 && smtpserver.count("*") > 0 
			&& smtpserver.count("_") > 0) {
			println "Invalid character in the SMTP server name"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CQSMTPServer", smtpserver)
	}
}

query {
	id "emailfromfield"
	required true
	dependencies features
	label "Text to use as the E-mail 'From' field"
	labelType "text"
	inputType "text"
	condition {
	   enableemailnotification.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.CQEmailFromField", emailfromfield)
	}
}