/*
 *+------------------------------------------------------------------------+
 *| Licensed Materials - Property of IBM                                   |
 *| (C) Copyright IBM Corp. 2012.  All Rights Reserved.              |
 *|                                                                        |
 *| US Government Users Restricted Rights - Use, duplication or disclosure |
 *| restricted by GSA ADP Schedule Contract with IBM Corp.                 |
 *+------------------------------------------------------------------------+
 */
query_script_version '1.0.0'

packageid 'com.ibm.rational.developer.zenterprise.v85'
packageversion '[8.5.0,9.0.0)'

query_order {
	custom {
		install {
			remotehelptype
			customremotehelpurl
			configurezosconnection
			hostname
			connectionname
			authenticationmethod
			daemonport
		}
		uninstall {
			
		}
		update {
			
		}
	}
}

query {
    id "remotehelptype"
    required true
    dependencies features
    label "Remote Help System"
    labelType "text"
    inputType "list"
    inputDefault "remote"
    inputOptions "remote,local,custom"
    inputIgnoreCase true
    condition {
        advancedType.equalsIgnoreCase("Yes")
    }
    validation {
    	//the value is automatically validated against inputOptions
    }
    action {
    	com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.help.option", remotehelptype)
    }
}

query {
    id "customremotehelpurl"
    required true
    dependencies features
    label "Remote Help URL"
    labelType "text"
    inputType "text"
    condition {
       remotehelptype.equalsIgnoreCase("custom")
    }
    validation {
    	if (!customremotehelpurl && customremotehelpurl.trim().length() <= 0) {
			println "The remote help URL is required. Please provide a value."
			return false
		}
    }
    action {
    	com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.help.url", customremotehelpurl)
    }
}

query {
	id "configurezosconnection"
	required true
	dependencies features
	label "Configure the z/OS connection now"
	labelType "text"
	inputType "list"
	inputDefault "No"
	inputOptions "Yes,No"
    inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (configurezosconnection.equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.remoteConfig.enabled", "true")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.remoteConfig.enabled", "false")
		}
	}
}

query {
	id "hostname"
	required true
	dependencies features
	label "z/OS connection host name"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes") && configurezosconnection.equalsIgnoreCase("Yes")
	}
	validation {
		if (hostname.count("/") > 0 && hostname.count("\\") > 0 && hostname.count("[") > 0 && hostname.count("]") > 0 && hostname.count("\"") > 0 
			&& hostname.count(":") > 0 && hostname.count(";") > 0 && hostname.count("|") > 0 && hostname.count("<") > 0 && hostname.count(">") > 0 
			&& hostname.count("+") > 0 && hostname.count("=") > 0 && hostname.count(",") > 0 && hostname.count("?") > 0 && hostname.count("*") > 0 
			&& hostname.count("_") > 0) {
			println "Invalid character in the SMTP server name"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.remoteConfig.hostname", hostname)
	}
}

query {
	id "connectionname"
	required true
	dependencies features
	label "z/OS connection name"
	labelType "text"
	inputType "text"
	inputDefault { 
		if (hostname) {
			hostname
		} 
		else {
			""
		} 
	}
	condition {
		advancedType.equalsIgnoreCase("Yes") && configurezosconnection.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.remoteConfig.connectionName", hostname)
	}
}

query {
	id "authenticationmethod"
	required true
	dependencies features
	label "z/OS connection authentication method"
	labelType "text"
	inputType "list"
	inputOptions "userid/password,certificate"
	inputDefault "userid/password"
	condition {
		advancedType.equalsIgnoreCase("Yes") && configurezosconnection.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (authenticationmethod.equalsIgnoreCase("userid/password")) {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.remoteConfig.authenticationMethod", "USERID")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.remoteConfig.authenticationMethod", "CERTIFICATE")			
		}
	}
}

query {
	id "daemonport"
	required true
	dependencies features
	label "z/OS connection daemon port"
	labelType "text"
	inputType "text"
	inputDefault "4035"
	condition {
		advancedType.equalsIgnoreCase("Yes") && configurezosconnection.equalsIgnoreCase("Yes")
	}
	validation {
		if (!daemonport.isInteger()) {
			println "The value must be an integer"
			return false
		}
		if ((daemonport.toInteger() < 1) || (daemonport.toInteger() > 65535)) {
			println "The port number must be between 1 and 65536"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setOfferingUserData(pkg, "user.remoteConfig.daemonPort", daemonport)
	}
}
