/*
 *+------------------------------------------------------------------------+
 *| Licensed Materials - Property of IBM                                   |
 *| (C) Copyright IBM Corp. 2012.  All Rights Reserved.              |
 *|                                                                        |
 *| US Government Users Restricted Rights - Use, duplication or disclosure |
 *| restricted by GSA ADP Schedule Contract with IBM Corp.                 |
 *+------------------------------------------------------------------------+
 */
query_script_version '1.0.0'

packageid 'com.ibm.team.install.calm'
packageversion '[3.0.0,3.1.0)'

query_order {
	custom {
		install {
			webapplocation
			contextrootoptions
			tomcatdisable
			noappserverdisable
			contextrootoverride
			shortcutkeyprefix
		}
		uninstall {
			tomcatdisable
			noappserverdisable
			contextrootoverride
			shortcutkeyprefix
			timestamp
		}
		update {
			tomcatdisable
			noappserverdisable
			contextrootoverride
			shortcutkeyprefix
			timestamp
		}
	}
}

query {
	id "webapplocation"
	required true
	dependencies features
	label "The Jazz Team Server web applications (WAR files) will be installed into the location specified. By default they will be placed in the 'server/webapps' directory. You may wish to specify an alternate location such as the webapps directory of an existing tomcat application server or a directory from which you typically deploy applications to your WebSphere Application Server. Location"
	labelType "text"
	inputType "text"
	inputDefault {
		if (platform == "linux") {
			"/opt/IBM/JazzTeamServer/server/webapps"
		}
		else if (platform == "win32") {
			"C:\\Program Files (x86)\\IBM\\JazzTeamServer\\server\\webapps"
		}
	}
	inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes") && !features.contains("com.ibm.team.install.jfs.offering.feature.id.tomcat")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.JazzFoundationServer.NoAppServer.WebApps.InstallLocation", webapplocation)
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.context-root-override", "true")
	}
}

query {
	id "contextrootoptions"
	required true
	dependencies features
	label "Use the following options to align the context roots of installed applications with context root values used in our deployment of previous product versions. Select an option"
	labelType "text"
	inputType "list"
	inputDefault "Use default 3.x application context roots"
	inputOptions {
		def roots = ["Use default 3.x application context roots"]
		
		if ((com.ibm.edp.rfe.model.ModelUtil.getScriptList().getCurrentScript() != null) && com.ibm.edp.rfe.model.ModelUtil.getFeatures(pkg).containsValue("rtc")) {
			roots = roots.plus("Use Rational Team Concert 2.x context root")
		}
		if ((com.ibm.edp.rfe.model.ModelUtil.getScriptList().getCurrentScript() != null) && com.ibm.edp.rfe.model.ModelUtil.getFeatures(pkg).containsValue("rqm")) {
			roots = roots.plus("Use Rational Quality Manager 2.x context root")
		}
		if ((com.ibm.edp.rfe.model.ModelUtil.getScriptList().getCurrentScript() != null) && com.ibm.edp.rfe.model.ModelUtil.getFeatures(pkg).containsValue("rdm")) {
			roots = roots.plus("Use Rational Requirements Composer 2.x context root")
		}
		roots
	}
	inputIgnoreCase true
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.jfs.app.admin.context-root", "admin")
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.jfs.app.jazz.context-root", "jts")
		if (contextrootoptions.equalsIgnoreCase("Use default 3.x application context roots")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.jfs.app.rtc.context-root", "ccm")
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.jfs.app.rqm.context-root", "qm")
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.jfs.app.rdm.context-root", "rm")
		}
		else if (contextrootoptions.equalsIgnoreCase("Use Rational Team Concert 2.x context root")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.jfs.app.rtc.context-root", "jazz")
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.jfs.app.rqm.context-root", "qm")
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.jfs.app.rdm.context-root", "rm")
		}
		else if (contextrootoptions.equalsIgnoreCase("Use Rational Quality Manager 2.x context root")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.jfs.app.rtc.context-root", "ccm")
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.jfs.app.rqm.context-root", "jazz")
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.jfs.app.rdm.context-root", "rm")

		}
		else if (contextrootoptions.equalsIgnoreCase("Use Rational Requirements Composer 2.x context root")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.jfs.app.rtc.context-root", "ccm")
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.jfs.app.rqm.context-root", "qm")
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.jfs.app.rdm.context-root", "rdm")

		}
	}
}

query {
	id "tomcatdisable"
	required true
	dependencies features
	label "Tomcat disable property"
	labelType "text"
	inputType "none"
	condition {
		// This will never be shown
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (features.contains("com.ibm.team.install.jfs.offering.feature.id.tomcat")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.jfs.appserver.tomcat.disable", "false")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.jfs.appserver.tomcat.disable", "true")
		}
	}
}

query {
	id "noappserverdisable"
	required true
	dependencies features
	label "No app server disable property"
	labelType "text"
	inputType "none"
	condition {
		// This will never be shown
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (features.contains("com.ibm.team.install.jfs.offering.feature.id.tomcat")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.jfs.appserver.noappserver.disable", "true")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.jfs.appserver.noappserver.disable", "false")
		}
		
	}
}

query {
	id "contextrootoverride"
	required true
	dependencies features
	label "Context root override property"
	labelType "text"
	inputType "none"
	inputDefault "true"
	condition {
		// This will never be shown
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.context-root-override", contextrootoverride)
	}
}

query {
	id "shortcutkeyprefix"
	required true
	dependencies features
	label "Shortcut key prefix property"
	labelType "text"
	inputType "none"
	condition {
		// This will never be shown
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (features.contains("rtc") || features.contains("rtc") || features.contains("rqm") || features.contains("rdm")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.jfs.migration-options.server-shortcut-key-prefix", "JazzTeamServerAndClmApps")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.jfs.migration-options.server-shortcut-key-prefix", "JazzTeamServer")
		}
		
	}
}

query {
	id "timestamp"
	required true
	dependencies features
	label "Timestamp property"
	labelType "text"
	inputType "none"
	inputDefault "true"
	condition {
		// This will never be shown
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		def now = new Date().format('yyyyMMdd-HHmm-ss')
		
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.com.ibm.team.install.prereq.timestamp", now)
	}
}
